# -*- coding: utf-8 -*-

"""
swaggerpetstoreopenapi30

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PetStatusEnum(object):

    """Implementation of the 'PetStatus' enum.

    pet status in the store

    Attributes:
        AVAILABLE: The enum member of type str.
        PENDING: The enum member of type str.
        SOLD: The enum member of type str.

    """
    AVAILABLE = 'available'

    PENDING = 'pending'

    SOLD = 'sold'

