# -*- coding: utf-8 -*-

"""
swaggerpetstoreopenapi30

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class OrderStatusEnum(object):

    """Implementation of the 'OrderStatus' enum.

    Order Status

    Attributes:
        PLACED: The enum member of type str.
        APPROVED: The enum member of type str.
        DELIVERED: The enum member of type str.

    """
    PLACED = 'placed'

    APPROVED = 'approved'

    DELIVERED = 'delivered'

